@@ -29,8 +29,8 @@ import gtk
 import gnomeapplet
 import gobject
 import dbus, dbus.service, dbus.mainloop.glib
+import locale
 
-import eds
 from configuration import conf, runtime, dialogs
 
 import stuff
@@ -199,6 +199,7 @@ class HamsterApplet(object):
         self.window = self._gui.get_object('hamster-window')
         # on close don't destroy the popup, just hide it instead
         self.window.connect("delete_event", lambda *args: self.__show_toggle(False))
+        self.window.connect("window-state-event", self.on_window_state_changed)
 
         self.new_name = widgets.ActivityEntry()
         self.new_name.connect("value-entered", self.on_switch_activity_clicked)
@@ -337,13 +338,6 @@ class HamsterApplet(object):
             self.notification.show()
 
 
-    def edit_cb(self, n, action):
-        dialogs.edit.show(self.applet, activity_id = self.last_activity['id'])
-
-    def switch_cb(self, n, action):
-        self.__show_toggle(not self.button.get_active())
-
-
     def load_day(self):
         """sets up today's tree and fills it with records
            returns information about last activity"""
@@ -383,7 +377,7 @@ class HamsterApplet(object):
             total_strings = []
             for category in by_category:
                 # listing of today's categories and time spent in them
-                duration = "%.1f" % (by_category[category] / 60.0)
+                duration = locale.format("%.1f", (by_category[category] / 60.0))
                 total_strings.append(_("%(category)s: %(duration)s") % \
                         ({'category': category,
                           #duration in main drop-down per category in hours
@@ -408,11 +402,10 @@ class HamsterApplet(object):
             delta = dt.datetime.now() - activity['start_time']
             duration = delta.seconds /  60
 
-            self.get_widget("last_activity_name").set_text(activity['name'])
             if activity['category'] != _("Unsorted"):
-                self.get_widget("last_activity_category") \
-                    .set_text(" - %s" % activity['category'])
-            self.get_widget("last_activity_category").show()
+                self.get_widget("last_activity_name").set_text("%s - %s" % (activity['name'], activity['category']))
+            else:
+                self.get_widget("last_activity_name").set_text(activity['name'])
 
 
             self._gui.get_object("more_info_button").hide()
@@ -427,7 +420,6 @@ class HamsterApplet(object):
             self.get_widget("start_tracking").show()
 
             self.get_widget("last_activity_name").set_text(_("No activity"))
-            self.get_widget("last_activity_category").hide()
 
             self.get_widget("activity_info_box").hide()
             self._gui.get_object("more_info_button").show()
@@ -447,14 +439,11 @@ class HamsterApplet(object):
             self.window.hide()
             return True
 
-        self.load_day() # reload day each time before showing to avoid outdated last activity
-        self.update_label() #update also label, otherwise we can get 1 minute difference in durations (due to timers refreshed once a minute)
-
         self.position_popup()
 
 
         # doing unstick / stick here, because sometimes while switching
-        # between workplaces window still manages to dissappear
+        # between workplaces window still manages to disappear
         self.window.unstick()
         self.window.stick() #show on all desktops
 
@@ -496,11 +485,22 @@ class HamsterApplet(object):
     def _delayed_display(self):
         """show window only when gtk has become idle. otherwise we get
         mixed results. TODO - this looks like a hack though"""
+        self.window.show()
         self.window.present()
         self.new_name.grab_focus()
 
+        self.load_day() # reload day each time before showing to avoid outdated last activity
+        self.update_label() #update also label, otherwise we can get 1 minute difference in durations (due to timers refreshed once a minute)
+
 
     """events"""
+    def on_window_state_changed(self, window, event):
+        """untoggle the button when window gets minimized"""
+        if (event.changed_mask & gtk.gdk.WINDOW_STATE_ICONIFIED \
+            and event.new_window_state & gtk.gdk.WINDOW_STATE_ICONIFIED):
+            self.button.set_active(False)
+
+
     def on_toggle(self, widget):
         self.__show_toggle(self.button.get_active())
 
@@ -614,7 +614,7 @@ class HamsterApplet(object):
 
                 activity = runtime.storage.get_activity_by_name(parsed_activity.activity_name,
                                                                 category_id,
-                                                                ressurect = False)
+                                                                resurrect = False)
                 if activity:
                     # we need dict below
                     activity = dict(name = activity['name'],
@@ -690,11 +690,13 @@ class HamsterApplet(object):
         self.get_widget("switch_activity").set_sensitive(widget.get_text() != "")
 
     def on_switch_activity_clicked(self, widget):
-        if not self.new_name.get_text():
+        activity_name, temporary = self.new_name.get_value()
+        if not activity_name:
             return False
 
         runtime.storage.add_fact(self.new_name.get_text().decode("utf8", "replace"),
-                                 self.new_tags.get_text().decode("utf8", "replace"))
+                                 self.new_tags.get_text().decode("utf8", "replace"),
+                                 temporary = temporary)
         self.new_name.set_text("")
         self.new_tags.set_text("")
         self.__show_toggle(False)
