@@ -113,8 +113,11 @@ class Storage(storage.Storage):
         self.__last_etag = self.__database_file.query_info(gio.FILE_ATTRIBUTE_ETAG_VALUE).get_etag()
 
     #tags, here we come!
-    def __get_tags(self):
-        return self.fetchall("select * from tags order by name")
+    def __get_tags(self, only_autocomplete = False):
+        if only_autocomplete:
+            return self.fetchall("select * from tags where autocomplete != 'false' order by name")
+        else:
+            return self.fetchall("select * from tags order by name")
 
     def __get_tag_ids(self, tags):
         """look up tags by their name. create if not found"""
@@ -124,7 +127,7 @@ class Storage(storage.Storage):
 
         changes = False
 
-        # check if any of tags needs ressurection
+        # check if any of tags needs resurrection
         set_complete = [str(tag["id"]) for tag in db_tags if tag["autocomplete"] == "false"]
         if set_complete:
             changes = True
@@ -247,7 +250,7 @@ class Storage(storage.Storage):
 
 
 
-    def __get_activity_by_name(self, name, category_id = None, ressurect = True):
+    def __get_activity_by_name(self, name, category_id = None, resurrect = True):
         """get most recent, preferably not deleted activity by it's name"""
 
         if category_id:
@@ -277,12 +280,9 @@ class Storage(storage.Storage):
             res = dict(res)
             res['deleted'] = res['deleted'] or False
 
-            # if the activity was marked as deleted, ressurect on first call
+            # if the activity was marked as deleted, resurrect on first call
             # and put in the unsorted category
-            if res['deleted'] and not ressurect:
-                return None
-
-            elif res['deleted']:
+            if res['deleted'] and resurrect:
                 update = """
                             UPDATE activities
                                SET deleted = null, category_id = -1
@@ -476,7 +476,8 @@ class Storage(storage.Storage):
 
 
     def __add_fact(self, activity_name, tags, start_time = None,
-                     end_time = None, category_name = None, description = None):
+                   end_time = None, category_name = None,
+                   description = None, temporary = False):
 
         activity = stuff.parse_activity_input(activity_name)
 
@@ -528,16 +529,16 @@ class Storage(storage.Storage):
             if not category_id:
                 category_id = self.__add_category(activity.category_name)
 
-        # try to find activity
+        # try to find activity, resurrect if not temporary
         activity_id = self.__get_activity_by_name(activity.activity_name,
-                                                  category_id)
+                                                  category_id,
+                                                  resurrect = not temporary)
         if not activity_id:
             activity_id = self.__add_activity(activity.activity_name,
-                                              category_id)
+                                              category_id, temporary)
         else:
             activity_id = activity_id['id']
 
-
         # if we are working on +/- current day - check the last_activity
         if (dt.datetime.now() - start_time <= dt.timedelta(days=1)):
 
@@ -745,39 +746,27 @@ class Storage(storage.Storage):
                       "DELETE FROM facts where id = ?"]
         self.execute(statements, [(fact_id,)] * 2)
 
-    def __get_activities(self, category_id = None):
+    def __get_category_activities(self, category_id):
         """returns list of activities, if category is specified, order by name
            otherwise - by activity_order"""
-        if category_id:
-            query = """
-                       SELECT a.id, a.name, a.activity_order, a.category_id, b.name as category
-                         FROM activities a
-                    LEFT JOIN categories b on coalesce(b.id, -1) = a.category_id
-                        WHERE category_id = ?
-                          AND deleted is null
-            """
-
-            # unsorted entries we sort by name - others by ID
-            if category_id == -1:
-                query += "ORDER BY lower(a.name)"
-            else:
-                query += "ORDER BY a.activity_order"
-
-            activities = self.fetchall(query, (category_id, ))
+        query = """
+                   SELECT a.id, a.name, a.activity_order, a.category_id, b.name as category
+                     FROM activities a
+                LEFT JOIN categories b on coalesce(b.id, -1) = a.category_id
+                    WHERE category_id = ?
+                      AND deleted is null
+        """
 
+        # unsorted entries we sort by name - others by ID
+        if category_id == -1:
+            query += "ORDER BY lower(a.name)"
         else:
-            query = """
-                       SELECT a.id, a.name, a.activity_order, a.category_id, b.name as category
-                         FROM activities a
-                    LEFT JOIN categories b on coalesce(b.id, -1) = a.category_id
-                        WHERE deleted IS NULL
-                     ORDER BY lower(a.name)
-            """
-            activities = self.fetchall(query)
+            query += "ORDER BY a.activity_order"
 
-        return activities
+        return self.fetchall(query, (category_id, ))
 
-    def __get_autocomplete_activities(self, search):
+
+    def __get_activities(self, search):
         """returns list of activities for autocomplete,
            activity names converted to lowercase"""
 
@@ -826,7 +815,7 @@ class Storage(storage.Storage):
                       "update activities set activity_order = ? where id = ?"],
                       [(priority1, id2), (priority2, id1)])
 
-    def __add_activity(self, name, category_id = None):
+    def __add_activity(self, name, category_id = None, temporary = False):
         # first check that we don't have anything like that yet
         activity = self.__get_activity_by_name(name, category_id)
         if activity:
@@ -836,11 +825,16 @@ class Storage(storage.Storage):
         category_id = category_id or -1
         new_order = self.fetchone("select max(activity_order) + 1  from activities")[0] or 1
 
+        deleted = None
+        if temporary:
+            deleted = 1
+
+
         query = """
-                   INSERT INTO activities (name, category_id, activity_order)
-                        VALUES (?, ?, ?)
+                   INSERT INTO activities (name, category_id, activity_order, deleted)
+                        VALUES (?, ?, ?, ?)
         """
-        self.execute(query, (name, category_id, new_order))
+        self.execute(query, (name, category_id, new_order, deleted))
         return self.__last_insert_rowid()
 
     def __update_activity(self, id, name, category_id):
@@ -1084,7 +1078,7 @@ class Storage(storage.Storage):
             # previously deleted records are now unsorted ones
             # user will be able to mark them as deleted again, in which case
             # they won't appear in autocomplete, or in categories
-            # ressurection happens, when user enters the exact same name
+            # resurrection happens, when user enters the exact same name
             self.execute("""
                                CREATE TABLE activities_new (id integer primary key,
                                                             name varchar2(500),
